Loading...
--- xnu/xnu-124.13/libsa/bootstrap.cpp
+++ xnu/xnu-344.49/libsa/bootstrap.cpp
@@ -3,19 +3,22 @@
*
* @APPLE_LICENSE_HEADER_START@
*
- * The contents of this file constitute Original Code as defined in and
- * are subject to the Apple Public Source License Version 1.1 (the
- * "License"). You may not use this file except in compliance with the
- * License. Please obtain a copy of the License at
- * http://www.apple.com/publicsource and read it before using this file.
+ * Copyright (c) 1999-2003 Apple Computer, Inc. All Rights Reserved.
*
* This Original Code and all software distributed under the License are
* distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
* EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
* INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT. Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
*
* @APPLE_LICENSE_HEADER_END@
*/
@@ -28,6 +31,8 @@
extern "C" {
#include <libsa/malloc.h>
};
+
+#include "kld_patch.h"
extern "C" {
/*****
@@ -49,8 +54,6 @@
* about loading and matching drivers.
*/
extern int kernelLinkerPresent;
-
-extern IOLock * kld_lock;
};
@@ -69,9 +72,6 @@
*/
KLDBootstrap::KLDBootstrap() {
- kld_lock = IOLockAlloc();
- IOLockLock(kld_lock);
-
kmod_load_function = &load_kernel_extension;
record_startup_extensions_function = &recordStartupExtensions;
@@ -79,8 +79,6 @@
remove_startup_extension_function = &removeStartupExtension;
kernelLinkerPresent = 1;
-
- IOLockUnlock(kld_lock);
}
/* The destructor frees all wired memory regions held
@@ -88,16 +86,15 @@
*/
KLDBootstrap::~KLDBootstrap() {
- OSDictionary * startupExtensions;
+ kld_file_cleanup_all_resources();
- IOLockLock(kld_lock);
+ /* Dump all device-tree entries for boot drivers, and all
+ * info on startup extensions. The IOCatalogue will now
+ * get personalities from kextd.
+ */
+ clearStartupExtensionsAndLoaderInfo();
+ /* Free all temporary malloc memory.
+ */
malloc_reset();
-
- startupExtensions = getStartupExtensions();
- if (startupExtensions) startupExtensions->release();
-
- IOLockUnlock(kld_lock);
- IOLockFree(kld_lock);
-
}
@@ -3,19 +3,22 @@
*
- * This Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
+ *
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
* EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
* INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,